@@ -1,14 +1,13 @@
+from __future__ import annotations
+
 from media_platform.lang.serialization import Deserializable
 
 
 class ExplicitContent(Deserializable):
-    def __init__(self, name, likelihood):
-        # type: (str, str) -> None
-        super(ExplicitContent, self).__init__()
+    def __init__(self, name: str, likelihood: str):
         self.name = name
         self.likelihood = likelihood
 
     @classmethod
-    def deserialize(cls, data):
-        # type: (dict) -> ExplicitContent
+    def deserialize(cls, data: dict) -> ExplicitContent:
         return ExplicitContent(data['name'], data['likelihood'])
