@@ -1,19 +1,17 @@
+from __future__ import annotations
+
 from media_platform.lang.serialization import Serializable
 
 
 class ExternalAuthorization(Serializable):
-    def __init__(self, headers):
-        # type: (dict) -> None
-        super(ExternalAuthorization, self).__init__()
-
+    def __init__(self, headers: dict):
         self.headers = headers
 
-    def serialize(self):
+    def serialize(self) -> dict:
         return {
             'headers': self.headers
         }
 
     @classmethod
-    def deserialize(cls, data):
-        # type: (dict) -> ExternalAuthorization
-        return cls(data['headers'])
\ No newline at end of file
+    def deserialize(cls, data: dict) -> ExternalAuthorization:
+        return cls(data['headers'])
