@@ -1,7 +1,6 @@
-class StreamErrorCode(object):
+class StreamErrorCode:
     success = 'success'
     invalid_stream_params = 'invalid_stream_params'
     stream_params_out_of_range = 'stream_params_out_of_range'
     dvr_upload_failed = 'dvr_upload_failed'
     stream_max_duration_reached = 'stream_max_duration_reached'
-
