@@ -1,22 +1,20 @@
+from __future__ import annotations
+
 from media_platform.exception.media_platform_exception import MediaPlatformException
 from media_platform.lang.serialization import Serializable, Deserializable
 
 
 class RestResult(Serializable, Deserializable):
-    def __init__(self, code, message, payload=None):
-        # type: (int, str, dict or list) -> None
-        super(RestResult, self).__init__()
-
+    def __init__(self, code: int, message: str, payload: dict or list = None):
         self.code = code
         self.message = message
         self.payload = payload
 
     @classmethod
-    def deserialize(cls, data):
-        # type: (dict) -> RestResult
+    def deserialize(cls, data: dict) -> RestResult:
         return RestResult(data['code'], data['message'], data.get('payload'))
 
-    def serialize(self):
+    def serialize(self) -> dict:
         return {
             'code': self.code,
             'message': self.message,
@@ -25,5 +23,5 @@ class RestResult(Serializable, Deserializable):
 
     def raise_for_code(self):
         if self.code != 0:
-            # todo: code -> exception mapper (Alon, have fun :))
+            # todo: code -> exception mapper
             raise MediaPlatformException()
